@@ -1,7 +1,7 @@
 from tiptapy import renderers
 
 
-def test_textnode():
+def _test_textnode():
     renderer = renderers.get('text')
     out = renderer.render({'type': 'text', 'text': 'text content'})
     print(out)
